@@ -1,4 +1,4 @@
-# $Id: /mirror/gungho/lib/Gungho/Log/Dispatch.pm 31120 2007-11-26T13:23:50.152702Z lestrrat  $
+# $Id: /mirror/gungho/lib/Gungho/Log/Dispatch.pm 3234 2007-10-13T15:12:58.068532Z lestrrat  $
 #
 # Copyright (c) 2007 Daisuke Maki <daisuke@endeworks.jp>
 # All rights reserved.
@@ -22,13 +22,11 @@ sub setup
 {
     my $self   = shift;
     my $c      = shift;
+    my $config = shift;
+    $self->next::method($c, @_);
 
-    $self->next::method($c);
-
-    my $config = $self->config || {};
     my $list = $config->{logs};
-
-    if ($list && ref $list ne 'ARRAY') {
+    if (ref $list ne 'ARRAY') {
         $list = [ $list ];
     }
 
@@ -91,21 +89,6 @@ Gungho::Log::Dispatch - Log::Dispatch-Based Log For Gungho
 
 =head1 SYNOPSIS
 
-  # in your Gungho config
-  log:
-    module: Dispatch
-    config:
-      logs:
-        - module: Screen
-          min_level: debug
-          name: stderr
-          stderr: 1
-        - module: File
-          min_level: info
-          filename: /path/tofilename
-          mode: append
-
-  # ... or somewhere in your code ..
   use Gungho::Log::Dispatch;
 
   my $log = Gungho::Log::Dispatch->new();
@@ -124,42 +107,6 @@ Gungho::Log::Dispatch - Log::Dispatch-Based Log For Gungho
     ]
   });
 
-=head1 DESCRIPTION
-
-This is the main log class for Gungho. It gives you the full power of
-Log::Dispatch for your needs.
-
-To use, specify something like this in your config:
-
-  log:
-    module: Dispatch
-    config:
-      logs:
-        - module: File
-          min_level: info
-          filename: /path/to/filename
-          name: logfile
-
-Each entry in the C<logs> section specifies one Log::Dispatch type. The
-C<module> parameter is taken as the Log::Dispatch subclass name, and it will
-be prefixed with the string "Log::Dispatch::". All other parameters are
-passed directly to the constructor.
-
-You may specify multiple logs to be added to the Log::Dispatch object.
-See the documentation for Log::Dispatch for details.
-
-To log, access the log object from $c:
-
-  $c->log->debug("This is a debug message");
-  $c->log->emergency("This is an emergency message");
-
-=head1 CAVEATS
-
-Do NOT use Log::Dispatch::File::Locked if you're running Gungho in a 
-multi-process environment. It's obvious if you think about it, but this is a 
-hard-to-debug problem because File::Locked will simply sit on its flock()
-wait while 1 Gungho process will merrily go processing requests.
-
 =head1 METHODS
 
 =head2 setup($c, \%config)
